<?php
/**
 * Recycling Energy functions and definitions
 *
 * @subpackage Recycling Energy
 * @since 1.0
 */

//woocommerce//
//shop page no of columns
function recycling_energy_woocommerce_loop_columns() {
	
	$retrun = get_theme_mod( 'recycling_energy_archieve_item_columns', 3 );
    
    return $retrun;
}
add_filter( 'loop_shop_columns', 'recycling_energy_woocommerce_loop_columns' );
function recycling_energy_woocommerce_products_per_page() {

		$retrun = get_theme_mod( 'recycling_energy_archieve_shop_perpage', 6 );
    
    return $retrun;
}
add_filter( 'loop_shop_per_page', 'recycling_energy_woocommerce_products_per_page' );
// related products
function recycling_energy_related_products_args( $args ) {
    $defaults = array(
        'posts_per_page' => get_theme_mod( 'recycling_energy_related_shop_perpage', 3 ),
        'columns'        => get_theme_mod( 'recycling_energy_related_item_columns', 3),
    );

    $args = wp_parse_args( $defaults, $args );

    return $args;
}
add_filter( 'woocommerce_output_related_products_args', 'recycling_energy_related_products_args' );
function recycling_energy_related_products_heading($recycling_energy_translated_text, $text, $domain) {
    $recycling_energy_heading = get_theme_mod('woocommerce_related_products_heading', 'Related products');

    if ($text === 'Related products' && $domain === 'woocommerce') {
        $recycling_energy_translated_text = $recycling_energy_heading;
    }
    return $recycling_energy_translated_text;
}
add_filter('gettext', 'recycling_energy_related_products_heading', 20, 3);
// breadcrumb seperator
function recycling_energy_woocommerce_breadcrumb_separator($recycling_energy_defaults) {
    $recycling_energy_separator = get_theme_mod('woocommerce_breadcrumb_separator', ' / ');

    // Update the separator
    $recycling_energy_defaults['delimiter'] = $recycling_energy_separator;

    return $recycling_energy_defaults;
}
add_filter('woocommerce_breadcrumb_defaults', 'recycling_energy_woocommerce_breadcrumb_separator');

//add animation class
if ( class_exists( 'WooCommerce' ) ) { 
	add_filter('post_class', function($recycling_energy_classes, $class, $product_id) {
	    if( is_shop() || is_product_category() ){
	        
	        $recycling_energy_classes = array_merge(['wow','swing'], $recycling_energy_classes);
	    }
	    return $recycling_energy_classes;
	},10,3);
}

//woocommerce-end//

// Get start function
function recycling_energy_custom_admin_notice() {
    // Check if the notice is dismissed
    if (!get_user_meta(get_current_user_id(), 'dismissed_admin_notice', true)) {
        // Check if not on the theme documentation page
        $recycling_energy_current_screen = get_current_screen();
        if ($recycling_energy_current_screen && $recycling_energy_current_screen->id !== 'appearance_page_recycling-energy-guide-page') {
            $recycling_energy_theme = wp_get_theme();
            ?>
            <div class="notice notice-info is-dismissible">
                <div class="notice-div">
                    <div>
                        <p class="theme-name"><?php echo esc_html($recycling_energy_theme->get('Name')); ?></p>
                        <p><?php _e('For information and detailed instructions, check out our theme documentation.', 'recycling-energy'); ?></p>
                    </div>
                    <a class="button-primary" href="themes.php?page=recycling-energy-guide-page"><?php _e('Theme Documentation', 'recycling-energy'); ?></a>
                </div>
            </div>
        <?php
        }
    }
}
add_action('admin_notices', 'recycling_energy_custom_admin_notice');
// Dismiss notice function
function recycling_energy_dismiss_admin_notice() {
    update_user_meta(get_current_user_id(), 'dismissed_admin_notice', true);
}
add_action('wp_ajax_recycling_energy_dismiss_admin_notice', 'recycling_energy_dismiss_admin_notice');
// Enqueue scripts and styles
function recycling_energy_enqueue_admin_script($hook) {
    // Admin JS
    wp_enqueue_script('recycling-energy-admin.js', get_theme_file_uri('/assets/js/recycling-energy-admin.js'), array('jquery'), true);

    wp_localize_script('recycling-energy-admin.js', 'recycling_energy_scripts_localize', array(
        'ajax_url' => esc_url(admin_url('admin-ajax.php'))
    ));
}
add_action('admin_enqueue_scripts', 'recycling_energy_enqueue_admin_script');
// Reset the dismissed notice status when the theme is switched
function recycling_energy_after_switch_theme() {
    delete_user_meta(get_current_user_id(), 'dismissed_admin_notice');
}
add_action('after_switch_theme', 'recycling_energy_after_switch_theme');
//get-start-function-end//

// tag count
function recycling_energy_display_post_tag_count() {
    $recycling_energy_tags = get_the_tags();
    $recycling_energy_tag_count = ($recycling_energy_tags) ? count($recycling_energy_tags) : 0;
    $recycling_energy_tag_text = ($recycling_energy_tag_count === 1) ? 'tag' : 'tags';
    echo $recycling_energy_tag_count . ' ' . $recycling_energy_tag_text;
}

//media post format
function recycling_energy_get_media($recycling_energy_type = array()){
	$recycling_energy_content = apply_filters( 'the_content', get_the_content() );
  	$output = false;

  // Only get media from the content if a playlist isn't present.
  if ( false === strpos( $recycling_energy_content, 'wp-playlist-script' ) ) {
    $output = get_media_embedded_in_content( $recycling_energy_content, $recycling_energy_type );
    return $output;
  }
}

//front page template
function recycling_energy_front_page_template( $recycling_energy_template ) {
	return is_home() ? '' : $recycling_energy_template;
}
add_filter( 'frontpage_template',  'recycling_energy_front_page_template' );

// excerpt function
function recycling_energy_custom_excerpt() {
    $recycling_energy_excerpt = get_the_excerpt();
    $recycling_energy_plain_text_excerpt = wp_strip_all_tags($recycling_energy_excerpt);
    
    // Get dynamic word limit from theme mod
    $recycling_energy_word_limit = esc_attr(get_theme_mod('recycling_energy_post_excerpt', '30'));
    
    // Limit the number of words
    $recycling_energy_limited_excerpt = implode(' ', array_slice(explode(' ', $recycling_energy_plain_text_excerpt), 0, $recycling_energy_word_limit));

    echo esc_html($recycling_energy_limited_excerpt);
}

// typography
function recycling_energy_fonts_scripts() {
	$recycling_energy_headings_font = esc_html(get_theme_mod('recycling_energy_headings_text'));
	$recycling_energy_body_font = esc_html(get_theme_mod('recycling_energy_body_text'));

	if( $recycling_energy_headings_font ) {
		wp_enqueue_style( 'recycling-energy-headings-fonts', '//fonts.googleapis.com/css?family='. $recycling_energy_headings_font );
	} else {
		wp_enqueue_style( 'recycling-energy-playfair-sans', '//fonts.googleapis.com/css?family=Playfair Display:ital,wght@0,400;0,500;0,600;0,700;0,800;0,900;1,400;1,500;1,600;1,700;1,800;1,900');
	}
	if( $recycling_energy_body_font ) {
		wp_enqueue_style( 'recycling-energy-body-fonts', '//fonts.googleapis.com/css?family='. $recycling_energy_body_font );
	} else {
		wp_enqueue_style( 'recycling-energy-jost-body', '//fonts.googleapis.com/css?family=Jost:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900');
	}
}
add_action( 'wp_enqueue_scripts', 'recycling_energy_fonts_scripts' );

// Footer Text
function recycling_energy_copyright_link() {
    $recycling_energy_footer_text = get_theme_mod('recycling_energy_footer_text', esc_html__('Recycling WordPress Theme', 'recycling-energy'));
    $recycling_energy_credit_link = esc_url('https://www.ovationthemes.com/wordpress/free-recycling-wordpress-theme/');

    echo '<a href="' . $recycling_energy_credit_link . '" target="_blank">' . esc_html($recycling_energy_footer_text) . '<span class="footer-copyright">' . esc_html__(' By Ovation Themes', 'recycling-energy') . '</span></a>';
}

function recycling_energy_sanitize_number_absint( $number, $setting ) {

	// Ensure input is an absolute integer.
	$number = absint( $number );

	// Get the input attributes associated with the setting.
	$atts = $setting->manager->get_control( $setting->id )->input_attrs;

	// Get minimum number in the range.
	$min = ( isset( $atts['min'] ) ? $atts['min'] : $number );

	// Get maximum number in the range.
	$max = ( isset( $atts['max'] ) ? $atts['max'] : $number );

	// Get step.
	$step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );

	// If the number is within the valid range, return it; otherwise, return the default
	return ( $min <= $number && $number <= $max && is_int( $number / $step ) ? $number : $setting->default );
}
// custom sanitizations
// dropdown
function recycling_energy_sanitize_dropdown_pages( $page_id, $setting ) {
	$page_id = absint( $page_id );
	return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}
// slider custom control
if ( ! function_exists( 'recycling_energy_sanitize_integer' ) ) {
	function recycling_energy_sanitize_integer( $input ) {
		return (int) $input;
	}
}
// range contol
// select post page
function recycling_energy_sanitize_select( $recycling_energy_input, $setting ){
    $recycling_energy_input = sanitize_key($recycling_energy_input);
    $choices = $setting->manager->get_control( $setting->id )->choices;
    return ( array_key_exists( $recycling_energy_input, $choices ) ? $recycling_energy_input : $setting->default );
}
// toggle switch
function recycling_energy_callback_sanitize_switch( $value ) {
	// Switch values must be equal to 1 of off. Off is indicator and should not be translated.
	return ( ( isset( $value ) && $value == 1 ) ? 1 : 'off' );
}
//choices control
function recycling_energy_sanitize_choices( $recycling_energy_input, $setting ) {
    global $wp_customize;
    $control = $wp_customize->get_control( $setting->id );
    if ( array_key_exists( $recycling_energy_input, $control->choices ) ) {
        return $recycling_energy_input;
    } else {
        return $setting->default;
    }
}
// Sanitize Sortable control.
function recycling_energy_sanitize_sortable( $val, $setting ) {
	if ( is_string( $val ) || is_numeric( $val ) ) {
		return array(
			esc_attr( $val ),
		);
	}
	$sanitized_value = array();
	foreach ( $val as $item ) {
		if ( isset( $setting->manager->get_control( $setting->id )->choices[ $item ] ) ) {
			$sanitized_value[] = esc_attr( $item );
		}
	}
	return $sanitized_value;
}

// customizer-dropdowns
function recycling_energy_slider_dropdown(){
	if(get_option('recycling_energy_slider_arrows') == true ) {
		return true;
	}
	return false;
}
function recycling_energy_services_dropdown(){
	if(get_option('recycling_energy_services_enable') == true ) {
		return true;
	}
	return false;
}
function recycling_energy_sanitize_phone_number( $phone ) {
  return preg_replace( '/[^\d+]/', '', $phone );
}
// theme setup
function recycling_energy_setup() {
	add_theme_support( 'woocommerce' );
	add_theme_support( "align-wide" );
	add_theme_support( "wp-block-styles" );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( "responsive-embeds" );
	add_theme_support( 'title-tag' );
	add_theme_support('custom-background',array(
		'default-color' => 'ffffff',
	));
	add_image_size( 'recycling-energy-featured-image', 2000, 1200, true );
	add_image_size( 'recycling-energy-thumbnail-avatar', 100, 100, true );

	$GLOBALS['content_width'] = 525;
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'recycling-energy' ),
	) );

	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'       => 250,
		'height'      => 250,
		'flex-width'  => true,
		'flex-height'  => true,
	) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );
	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array('image','video','gallery','audio','quote',) );
	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, and column width.
 	 */
	add_editor_style( array( 'assets/css/editor-style.css', recycling_energy_fonts_url() ) );
}
add_action( 'after_setup_theme', 'recycling_energy_setup' );

// widgets
function recycling_energy_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'recycling-energy' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'recycling-energy' ),
		'before_widget' => '<section id="%1$s" class="widget wow zoomIn %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'recycling-energy' ),
		'id'            => 'sidebar-2',
		'description'   => __( 'Add widgets here to appear in your pages and posts', 'recycling-energy' ),
		'before_widget' => '<section id="%1$s" class="widget wow zoomIn %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar 3', 'recycling-energy' ),
		'id'            => 'sidebar-3',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'recycling-energy' ),
		'before_widget' => '<section id="%1$s" class="widget wow zoomIn %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer 1', 'recycling-energy' ),
		'id'            => 'footer-1',
		'description'   => __( 'Add widgets here to appear in your footer.', 'recycling-energy' ),
		'before_widget' => '<section id="%1$s" class="widget wow slideInLeft %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'recycling-energy' ),
		'id'            => 'footer-2',
		'description'   => __( 'Add widgets here to appear in your footer.', 'recycling-energy' ),
		'before_widget' => '<section id="%1$s" class="widget wow slideInLeft %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'recycling-energy' ),
		'id'            => 'footer-3',
		'description'   => __( 'Add widgets here to appear in your footer.', 'recycling-energy' ),
		'before_widget' => '<section id="%1$s" class="widget wow slideInRight %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'recycling-energy' ),
		'id'            => 'footer-4',
		'description'   => __( 'Add widgets here to appear in your footer.', 'recycling-energy' ),
		'before_widget' => '<section id="%1$s" class="widget wow slideInRight %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'recycling_energy_widgets_init' );

// gooogle fonts
function recycling_energy_fonts_url(){
	$font_url = '';
	$font_family = array();
	$font_family[] = 'Be Vietnam Pro:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900';
	$font_family[] = 'Poppins:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900';
	$recycling_energy_query_args = array(
		'family'	=> rawurlencode(implode('|',$font_family)),
	);
	$font_url = add_query_arg($recycling_energy_query_args,'//fonts.googleapis.com/css');
	return $font_url;
	$contents = wptt_get_webfont_url( esc_url_raw( $fonts_url ) );
}

//Enqueue scripts and styles.
function recycling_energy_scripts() {

	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'recycling-energy-fonts', recycling_energy_fonts_url(), array());

	//Bootstarp
	wp_enqueue_style( 'bootstrap-style', get_template_directory_uri().'/assets/css/bootstrap.css' );

	// Theme stylesheet.
	wp_enqueue_style( 'recycling-energy-style', get_stylesheet_uri() );

	// Theme Customize CSS.
	require get_parent_theme_file_path( 'inc/extra_customization.php' );
	wp_add_inline_style( 'recycling-energy-style',$recycling_energy_custom_style );

	//font-awesome
	wp_enqueue_style( 'font-awesome-style', get_template_directory_uri().'/assets/css/fontawesome-all.css' );

	//owl-carousel
	wp_enqueue_style( 'owl-carousel-style', get_template_directory_uri().'/assets/css/owl.carousel.css' );

	// Block Style
	wp_enqueue_style( 'recycling-energy-block-style',get_template_directory_uri().'/assets/css/blocks.css' );

	//Custom JS
	wp_enqueue_script( 'recycling-energy-custom.js', get_theme_file_uri( '/assets/js/theme-script.js' ), array( 'jquery' ), true );

	//Nav Focus JS
	wp_enqueue_script( 'recycling-energy-navigation-focus', get_theme_file_uri( '/assets/js/navigation-focus.js' ), array( 'jquery' ), true );

	//Bootstarp JS
	wp_enqueue_script( 'bootstrap-js', get_theme_file_uri( '/assets/js/bootstrap.js' ), array( 'jquery' ),true );

	//Owl-carousel JS
	wp_enqueue_script( 'owl-carousel-js', get_theme_file_uri( '/assets/js/owl.carousel.js' ), array( 'jquery' ),true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if (get_option('recycling_energy_animation_enable', false) !== 'off') {
		//wow.js
		wp_enqueue_script( 'recycling-energy-wow-js', get_theme_file_uri( '/assets/js/wow.js' ), array( 'jquery' ), true );

		//animate.css
		wp_enqueue_style( 'recycling-energy-animate-css', get_template_directory_uri().'/assets/css/animate.css' );
	}
}
add_action( 'wp_enqueue_scripts', 'recycling_energy_scripts' );

function recycling_energy_block_editor_styles() {
	// Block styles.
	wp_enqueue_style( 'recycling-energy-block-editor-style', trailingslashit( esc_url ( get_template_directory_uri() ) ) . '/assets/css/editor-blocks.css' );

	// Add custom fonts.
	wp_enqueue_style( 'recycling-energy-fonts', recycling_energy_fonts_url(), array() );
}
add_action( 'enqueue_block_editor_assets', 'recycling_energy_block_editor_styles' );

# Load scripts and styles.(fontawesome)
add_action( 'customize_controls_enqueue_scripts', 'recycling_energy_customize_controls_register_scripts' );
function recycling_energy_customize_controls_register_scripts() {
	
	wp_enqueue_style( 'recycling-energy-ctypo-customize-controls-style', trailingslashit( esc_url(get_template_directory_uri()) ) . '/assets/css/customize-controls.css' );
}

//enque files
require get_parent_theme_file_path( '/inc/custom-header.php' );
require get_parent_theme_file_path( '/inc/template-tags.php' );
require get_parent_theme_file_path( '/inc/template-functions.php' );
require get_parent_theme_file_path( '/inc/customizer.php' );
require get_parent_theme_file_path( '/inc/typography.php' );
require get_parent_theme_file_path( '/inc/dashboard/dashboard.php' );
require get_parent_theme_file_path( '/inc/wptt-webfont-loader.php' );
require get_parent_theme_file_path( '/inc/breadcrumb.php' );
require get_parent_theme_file_path( 'inc/sortable/sortable_control.php' );